<template>
  <a-modal
    :title='title'
    :width='1200'
    :visible='visible'
    :maskClosable='false'
    @ok='handleOk'
    cancelText='关闭'
    @cancel='handleCancel'
    :confirmLoading='confirmLoading'
  >
    <a-spin :spinning='confirmLoading'>
      <a-form-model :form='form' ref='form' :model='model' :rules='validatorRules'>
        <a-row :span='24'>
          <a-col :span='12'>
            <a-form-model-item label='单据号' :labelCol='labelCol' :wrapperCol='wrapperCol' prop='num'>
              <a-input v-model='model.num' placeholder='请输入单据号' :disabled="disableSubmit"></a-input>
            </a-form-model-item>
          </a-col>
          <a-col :span='12'>
            <a-form-model-item label='业务类型' :labelCol='labelCol' :wrapperCol='wrapperCol' prop='businessType'>
              <j-dict-select-tag
                allow-clear
                :disabled='disableSubmit'
                v-model='model.businessType'
                :placeholder="disableSubmit?'':'请选择类型'"
                :triggerChange='true'
                dictCode='business_type'
              />
            </a-form-model-item>
          </a-col>
          </a-row>
            <a-row :span='24'>
          <a-col :span='12'>
            <a-form-model-item label='使用部门' :labelCol='labelCol' :wrapperCol='wrapperCol' prop='useDepartId'>
              <a-select
                placeholder='请选择'
                v-model='model.useDepartId'
                :disabled="disableSubmit"
                :options='this.departVoList'
                style='width: 100%'
              />
            </a-form-model-item>
          </a-col>

          <a-col :span='12'>
            <a-form-model-item label='备注' :labelCol='labelCol' :wrapperCol='wrapperCol' prop='remark'>
              <a-textarea v-model='model.remark'  placeholder='请输入备注' :disabled="disableSubmit"></a-textarea>
            </a-form-model-item>
          </a-col>

        </a-row>
      </a-form-model>
    </a-spin>
    <a-button
      type='primary'
      :style="{ marginRight: '8px',marginBottom:'8px' }"
      :loading='confirmLoading'
      @click='selectInspectionProjects()'
    >设备信息
    </a-button>
    <a-table
      ref='table'
      bordered
      size='middle'
      rowKey='id'
      :columns='columns'
      :dataSource='dataSource'
      :scroll='{ x: 1450, y: 1000 }'
    >
      <template
        v-for='col in columns'
        :slot='col.dataIndex'
        slot-scope='text, record, index'
      >
        <div :key='col.dataIndex'>


          <a-date-picker
            :value='text'
            :disabled="disableSubmit"
            v-if="col.dataIndex == 'actualBorrowDate'"
            format='YYYY-MM-DD HH:mm:ss'
            @change='(e)=>handleChange(e, record.key, col, index)'
          />

        </div>
      </template>
      <span
        slot='action'
        slot-scope='text, record, index'
      >
        <a-popconfirm
          title='确定删除吗?'
          :disabled="disableSubmit"
          @confirm='() => handleDelete(text,record, index)'
        >
          <a>删除</a>
        </a-popconfirm>
      </span>
    </a-table>
    <template slot='footer'>
      <a-button
        :style="{marginRight: '8px'}"
        @click='handleCancel()'
      >
        关闭
      </a-button>

      <a-button
        @click='handleOk()'
        type='primary'
        :disabled="disableSubmit"
        :loading='confirmLoading'
      >确定
      </a-button>
    </template>
    <j-select-equipment-modal ref='equipmentUnloadingBorrowModalForm'></j-select-equipment-modal>
  </a-modal>

</template>

<script>
import { getAction, postAction, requestPut } from '@/api/manage'
import JMultiSelectTag from '@/components/dict/JMultiSelectTag'
import Tooltip from 'ant-design-vue/es/tooltip'

import pick from 'lodash.pick'
import { validateDuplicateValue } from '@/utils/util'
import JSelectEquipmentModal from '@views/common/JSelectEquipmentModal'
export default {
  name: 'EquipmentUnloadingBorrowDetailModal',
  components: {
    JMultiSelectTag,
    Tooltip,
    JSelectEquipmentModal,

  },
  data() {
    return {
      replaceFields: {
        value: 'key'
      },
      columns: [
        {
          title: '#',
          dataIndex: '',
          key: 'rowIndex',
          align: 'center',
          customRender: function(t, r, index) {
            return parseInt(index) + 1
          },
          width: 100
        },

        {
          title: '设备状态',
          align: 'center',
          width: 100,
          dataIndex: 'equipmentStatus'
        },
        {
          title: '统一编码',
          align: 'center',
          width: 100,
          dataIndex: 'equipmentNum'
        },
        {
          title: '设备名称',
          align: 'center',
          width: 150,
          dataIndex: 'equipmentName'
        },
        {
          title: '规格',
          width: 100,
          align: 'center',
          dataIndex: 'specification'
        },
        {
          title: '型号',
          width: 100,
          align: 'center',
          dataIndex: 'model'
        },
        {
          title: '技术状态',
          align: 'center',
          width: 100,
          dataIndex: 'technicalStatus'
        },

        {
          title: '实际领借日期',
          align: 'center',
          width: 200,
          dataIndex: 'actualBorrowDate',
          scopedSlots: {
            customRender: 'actualBorrowDate'
          }

        },

        {
          title: '责任班组',
          align: 'center',
          width: 150,
          dataIndex: 'responsibilityTeamName'

        },
        {
          title: '责任人',
          align: 'center',
          dataIndex: 'responsibilityUserName'
        },
        {
          title: '操作',
          align: 'center',
          fixed: 'right',
          width: 150,
          dataIndex: 'action',
          scopedSlots: {
            customRender: 'action'
          }
        }
      ],
      title: '操作',
      visible: false,
      visible4Confirm: false,
      disableSubmit: false,
      codeDisable: true,
      model: {},
      dateFormat: 'YYYY-MM-DD HH:mm:ss',
      workOrder: {
        value: '',
        text: '',
        title: ''
      },
      labelCol: {
        xs: { span: 24 },
        sm: { span: 5 }
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 16 }
      },
      confirmLoading: false,
      form: this.$form.createForm(this),
      validatorRules: {
        num: [
          { required: true, message: '请输入单号!' },
          { validator: (rule, value, callback) => validateDuplicateValue('mom_eam_equipment_unloading', 'num', value, this.model.id, callback) }
        ],

        businessType: [
          { required: true, message: '请选择业务类型!' }

        ],
        useDepartId: [
          { required: true, message: '请选择使用部门!' }

        ]


      },


      url: {
        add: '/eam/equipmentUnloading/add',
        edit: '/eam/equipmentUnloading/edit',
        departVoList: 'eam/equipmentUnloadingBorrowDetail/getDepart'


      },
      departVoList: [],
      dataSource: []


    }
  },
  created() {
    //备份model原始值
    this.getInDepartList()
  },

  mounted() {
    this.$bus.$on('selectionRows', (data) => {
      for (let i = 0; i < data.length; i++) {
        this.dataSource.push({
          id: data[i].id,
          equipmentId: data[i].id,
          equipmentNum: data[i].num,
          equipmentName: data[i].name,
          model: data[i].model,
          specification: data[i].specification,
          technicalStatus: data[i].technologyStatus_dictText,
          responsibilityTeamId: data[i].teamId,
          responsibilityUserId: data[i].functionary,
          responsibilityUserName:data[i].functionary_dictText,
          responsibilityTeamName:data[i].teamId_dictText,
          equipmentStatus:data[i].equipmentStatus_dictText
        })
      }

    })
  },


  methods: {

    /*获取部门列表*/
    getInDepartList() {
      getAction(this.url.departVoList).then((res) => {
        if (res.success) {
          this.departVoList = res.result

        } else {
          this.$message.warn(res.message)
        }
      })
    },

    //选择点检项目
    selectInspectionProjects: function() {
      let ids = []
      for (let i = 0; i < this.dataSource.length; i++) {
        ids.push(this.dataSource[i].equipmentId)
      }
      this.$refs.equipmentUnloadingBorrowModalForm.showModals(ids)
      this.$refs.equipmentUnloadingBorrowModalForm.title = '选择设备信息'
      this.$refs.equipmentUnloadingBorrowModalForm.disableSubmit = false
    },

    add() {
      this.model.unloadingType = 'borrow'
      this.edit(this.model, { equipmentUnloadingBorrowDetailList: [] })
    },


    edit(record) {
      let that = this
      that.dataSource = []
      this.form.resetFields()
      this.model = Object.assign({}, record)
      this.visible = true
      if (record.equipmentUnloadingBorrowDetailList != undefined) {
        const temp = [...record.equipmentUnloadingBorrowDetailList]
        that.dataSource = temp
      }

      that.$nextTick(() => {
        that.form.setFieldsValue(pick(that.model, 'num', 'inEnterpriseId', 'outEnterpriseId', 'remark'))
      })
      if (record.id) {
        this.codeDisable = true
      } else {
        this.codeDisable = false
      }
    },


    close() {
      this.$emit('close')
      this.visible = false
    },

    handleCancel() {
      this.close()
    },

    handleChange(value, key, column, index) {
      let that = this
      const temp = [...that.dataSource]
      const target = temp.filter(item => key === item.key)[index]
      if (target) {

        if (column.dataIndex == 'actualBorrowDate') {

          target[column.dataIndex] = value
        }
        //显示带过来的数据
        that.dataSource = temp

      }
    },
    handleOk() {
      const that = this
      this.$refs.form.validate(valid => {
        if (valid) {
          that.confirmLoading = true
          let formData = Object.assign(this.model, valid)
          formData.equipmentUnloadingBorrowDetailList = that.dataSource
          if (that.dataSource.length ===0){
            that.confirmLoading = false
            that.$message.warning("请添加领借明细")
            return
          }
          for (let annItem of that.dataSource) {
            if (annItem.actualBorrowDate == undefined || annItem.actualBorrowDate == null || annItem.actualBorrowDate == '') {
              that.$message.warning('请填写实际领借时间')
              that.confirmLoading = false
              return
            }
          }
          let obj
          if (!this.model.id) {
            obj = postAction(this.url.add, formData)
          } else {
            obj = requestPut(this.url.edit, formData, { id: this.model.id })
          }
          obj.then((res) => {
            if (res.success) {
              that.$message.success(res.message)
              that.$emit('ok')
            } else {
              that.$message.warning(res.message)
            }
          }).finally(() => {
            this.model = {}
            that.confirmLoading = false
            this.$set(this.model, 'auditStatus', 'notSubmitted')
            that.close()
          })
        }
      })
    },


    handleDelete(text, record, index) {
      this.dataSource.splice(index, 1)

    }


  }

}
</script>

<style lang='less' scoped>
/deep/ .frozenRowClass {
  color: #c9c9c9;
}

.fontweight {
  font-weight: bold;
}

.ant-btn {
  padding: 0 10px;
  margin-left: 3px;
}

.ant-form-item-control {
  line-height: 0px;
}

/** 主表单行间距 */
.ant-form .ant-form-item {
  margin-bottom: 10px;
}

/** Tab页面行间距 */
.ant-tabs-content .ant-form-item {
  margin-bottom: 0px;
}
</style>